import type { Ref } from "vue";
export type DataType = "text" | "json" | "blob" | "arrayBuffer" | "formData";
export type HttpMethod = "GET" | "POST" | "PUT" | "DELETE" | "PATCH" | "HEAD" | "OPTIONS";
export type BeforeAjaxFunction<T = any> = (context: T, cancel: (cancel: boolean) => void) => void | Promise<void>;
export type BeforeAjaxFunctions<T = any> = BeforeAjaxFunction<T>[];
export type TransformDataFunction<T = any, R = any> = (res: Response, context: T) => R | Promise<R>;
export type TransformPayloadFunction<T = any> = (data: unknown, context: T) => unknown | Promise<unknown>;
export type ParamType = Record<string, string | number | boolean>;
export type QueryType = Record<string, unknown>;
export type AjaxOptions = {
    uniqueId: string;
    baseUrl: string;
    dataType: DataType;
    relativeUrl: string;
    payload: unknown;
    useCache: boolean;
    cacheName: string;
    params: ParamType;
    queries: QueryType;
    group: string;
    timeout: number;
    cancelled: boolean;
};
export type AjaxState<T> = {
    isRequesting: Ref<boolean>;
    isReady: Ref<boolean>;
    isFinished: Ref<boolean>;
    data: Ref<null | T>;
    error: Ref<null | CommonAjaxError>;
};
export type CommonAjaxError = {
    code?: number;
    message: string;
    url: string;
    error?: unknown;
    response?: Response;
};
